/*
 * Copyright (c) 2014, Sonos, Inc.
 *
 * SPDX-License-Identifier:	GPL-2.0
 *
 * SONOS LED control
 *
 * Data structures shared between the kernel and user space
 */
#ifndef SONOS_LED_H
#define SONOS_LED_H

struct led_step {
    uint8_t	r;
    uint8_t	g;
    uint8_t	b;
    uint8_t	reserved;

    uint16_t	hold_time;
    uint16_t	fade;
};

struct led_pattern {
	uint8_t		cksum[20];
	uint16_t	flags;
	uint8_t		repeats;
	uint8_t		num_steps;
	struct led_step	*step_array;
};

#define LED_CTL_DEFAULT			0x0000
#define LED_CTL_ENQUEUE			0x0001
#define LED_CTL_INTERRUPT		0x0002
#define LED_CTL_OVERRIDE_FEEDBACK	0x0004
#define LED_CTL_AUDIODEV_WHITE		0x0008

#define LED_CTL_MAX_STEPS		32

#if defined(SONOS_ARCH_BOOTLEG)
enum LED_COLOR {
    LED_RED_CLR         =   0xd0000b,
    LED_GREEN_CLR       =   0x35e500,
    LED_BLUE_CLR        =   0x0000ff,
    LED_AMBER_CLR       =   0xff5a00,
    LED_YELLOW_CLR      =   0xffff55,
    LED_PURPLE_CLR      =   0xff55ff,
    LED_OFF             =   0x000000,
    LED_DIM_WHITE_CLR   =   0x555555,
    LED_WHITE_CLR       =   0xf3f3f3,
};
#elif defined(SONOS_ARCH_ENCORE) || defined(SONOS_ARCH_SOLBASE)
enum LED_COLOR {
    LED_RED_CLR         =   0xd0021b,
    LED_GREEN_CLR       =   0x55d000,
    LED_BLUE_CLR        =   0x0000ff,
    LED_AMBER_CLR       =   0xff5000,
    LED_YELLOW_CLR      =   0xffff55,
    LED_PURPLE_CLR      =   0xff55ff,
    LED_OFF             =   0x000000,
    LED_DIM_WHITE_CLR   =   0x6f6f6f,
    LED_WHITE_CLR       =   0xf3f3f3,
};
#else
enum LED_COLOR {
    LED_RED_CLR         =   0xff0000,
    LED_GREEN_CLR       =   0x00ff00,
    LED_BLUE_CLR        =   0x0000ff,
    LED_AMBER_CLR       =   0xff5000,
    LED_YELLOW_CLR      =   0xffff55,
    LED_PURPLE_CLR      =   0x800080,
    LED_OFF             =   0x000000,
    LED_DIM_WHITE_CLR   =   0x4f4f4f,
    LED_WHITE_CLR       =   0xffffff,
};
#endif

#endif
